StoneStartPosition class

Relative start position of a stone in the Wall.

Constructors

StoneStartPosition({required int x, required int y})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → int
Wall column position.
final
y → int
Wall row position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator *(Size stoneSide) → Offset
Computes the absolute brick position in a wall. stoneSide represents the smallest stone width/height.
operator ==(Object other) → bool
The equality operator.
inherited